#
#      File name: read.s
#
#      Reads data: various parameters, claims data and exposure data
#      Defines data matrices and vectors for claims and exposures
#
#      Parameters.dat contains the following information
#
#         minimum age, maximum age
#         minimum year, maximum year
#         stop.year: this should be set to 1974 to produce
#         the results in the paper.  Other values could be set.
#         P-spline parameters for age: ndx.a bdeg.a pord.a
#         P-spline parameters for year: ndx.y bdeg.y pord.y
#
#      ========================================================
#
#      Read data
#
Parameters <- scan("Parameters.dat", sep = " ")
min.age <- Parameters[1]
max.age <- Parameters[2]
min.year <- Parameters[3]
max.year <- Parameters[4]
stop.year <- Parameters[5]
#
#      P-spline parameters for age
#
ndx.a <- Parameters[6]
bdeg.a <- Parameters[7]
pord.a <- Parameters[8]
#
#      P-spline parameters for year
#
ndx.y <- Parameters[9]
bdeg.y <- Parameters[10]
pord.y <- Parameters[11]
#
#      Claims data
#
D <- scan("Claims.dat", sep = " ")
D <- matrix(D, nrow = (max.year - min.year + 1),
               ncol = (max.age - min.age + 1))
D <- t(D)
dimnames(D) <- list(min.age: max.age, min.year: max.year)
d <- c(D)
#
#      Exposure data
#
E <- scan("Exposure.dat", sep = " ")
E <- matrix(E, nrow = (max.year - min.year + 1),
               ncol = (max.age - min.age + 1))
E <- t(E)
dimnames(E) <- list(min.age: max.age, min.year: max.year)
e <- c(E)
off <- log(e)
