#
#      File name: setup_2d.s
#
#      Setup file to do analysis in first half of section 4.1
#
#      Prepares data vectors, loads functions, 
#      calculates regression and penalty matrices,
#      obtains initial estimate of a
#
#      ========================================================
#
#      Read data
#
source("read.s")
#
#      Calculate weight vector to match data for years 47-74 and
#      and missing data for 75-99
#
V <- matrix(0, nrow = nrow(D), ncol = ncol(D))
dimnames(V) <- list(min.age: max.age, min.year: max.year)
V[ ,1:length(min.year:stop.year)] <- 1
v <- c(V)
#
#      Load functions
#
source("Functions.s")
#
options(object.size = 1e8)
#
#    Calculate regression and penalty matrices
#
#    Age
#
x.a <- 1:nrow(D)
x.a.l <- min(x.a) - 1
x.a.r <- max(x.a) + 1
Calc.P <- setup.P(x.a, x.a.l, x.a.r, bdeg.a, pord.a, ndx.a)
B.a <- Calc.P$B
DtD.a <- Calc.P$DtD
#
#    Year
#
x.y <- 1:ncol(D)
x.y.l <- min(x.y) - 1
x.y.r <- max(x.y) + 1
Calc.P <- setup.P(x.y, x.y.l, x.y.r, bdeg.y, pord.y, ndx.y)
B.y <- Calc.P$B
DtD.y <- Calc.P$DtD

#
#    Calculate Kronecker product regression and penalty matrices
#
B <- kronecker(B.y, B.a)
P.a <- kronecker( diag(ncol(B.y)), DtD.a )
P.y <- kronecker( DtD.y, diag(ncol(B.a)) )
#
#    Initialise a
#
eta <- matrix(log( (d+1)/(e+2) ), nrow = nrow(B), ncol = 1)
a.init <- solve( t(B) %*% B, t(B) %*% eta)

